@@ -21,7 +21,7 @@ class Comformity:
             metadata: dict,
             category: str,
             code_area: list,
-            code_area_level: str,
+            code_area_level: str
     ):
         self.data = data.copy()
         self.title = title
@@ -173,7 +173,7 @@ class Comformity:
                 on=['kode_provinsi', 'nama_provinsi', 'kode_kabupaten_kota', 'nama_kabupaten_kota'],
                 indicator=True
             )
-        if self.code_area_level == 'province':
+        elif self.code_area_level == 'province':
             code_area = pd.DataFrame(self.code_area)[['kode_provinsi', 'nama_provinsi']].drop_duplicates()
             result = dataframe.merge(
                 code_area,
@@ -181,6 +181,9 @@ class Comformity:
                 on=['kode_provinsi', 'nama_provinsi'],
                 indicator=True
             )
+        else:
+            result = dataframe.copy()
+            result['_merge'] = 'left_only'
 
         total_rows = len(dataframe.index)
         total_columns = len(dataframe.columns)
